@@ -11,6 +11,7 @@ This module provides a simple and elegant wrapper for colorama.
 
 from __future__ import absolute_import
 
+import os
 import re
 import sys
 
@@ -37,29 +38,36 @@ else:
     DISABLE_COLOR = False
 
 
-
 class ColoredString(object):
     """Enhanced string for __len__ operations on Colored output."""
-    def __init__(self, color, s, always_color=False):
+    def __init__(self, color, s, always_color=False, bold=False):
         super(ColoredString, self).__init__()
         self.s = s
         self.color = color
         self.always_color = always_color
+        self.bold = bold
+        if os.environ.get('CLINT_FORCE_COLOR'):
+            self.always_color = True
 
     def __getattr__(self, att):
-             def func_help(*args, **kwargs):
-                 result = getattr(self.s, att)(*args, **kwargs)
-                 if isinstance(result, basestring):
-                     return self._new(result)
-                 elif isinstance(result, list):
-                     return [self._new(x) for x in result]
-                 else:
-                     return result
-             return func_help
+        def func_help(*args, **kwargs):
+            result = getattr(self.s, att)(*args, **kwargs)
+            try:
+                is_result_string = isinstance(result, basestring)
+            except NameError:
+                is_result_string = isinstance(result, str)
+            if is_result_string:
+                return self._new(result)
+            elif isinstance(result, list):
+                return [self._new(x) for x in result]
+            else:
+                return result
+        return func_help
 
     @property
     def color_str(self):
-        c = '%s%s%s' % (getattr(colorama.Fore, self.color), self.s, colorama.Fore.RESET)
+        style = 'BRIGHT' if self.bold else 'NORMAL'
+        c = '%s%s%s%s%s' % (getattr(colorama.Fore, self.color), getattr(colorama.Style, style), self.s, colorama.Fore.RESET, getattr(colorama.Style, 'NORMAL'))
 
         if self.always_color:
             return c
@@ -85,7 +93,10 @@ class ColoredString(object):
         __str__ = __unicode__
     else:
         def __str__(self):
-            return unicode(self).encode('utf8')
+            value = self.color_str
+            if isinstance(value, bytes):
+                return value
+            return value.encode('utf8')
 
     def __iter__(self):
         return iter(self.color_str)
@@ -113,29 +124,29 @@ def clean(s):
     return txt
 
 
-def black(string, always=False):
-    return ColoredString('BLACK', string, always_color=always)
+def black(string, always=False, bold=False):
+    return ColoredString('BLACK', string, always_color=always, bold=bold)
 
-def red(string, always=False):
-    return ColoredString('RED', string, always_color=always)
+def red(string, always=False, bold=False):
+    return ColoredString('RED', string, always_color=always, bold=bold)
 
-def green(string, always=False):
-    return ColoredString('GREEN', string, always_color=always)
+def green(string, always=False, bold=False):
+    return ColoredString('GREEN', string, always_color=always, bold=bold)
 
-def yellow(string, always=False):
-    return ColoredString('YELLOW', string, always_color=always)
+def yellow(string, always=False, bold=False):
+    return ColoredString('YELLOW', string, always_color=always, bold=bold)
 
-def blue(string, always=False):
-    return ColoredString('BLUE', string, always_color=always)
+def blue(string, always=False, bold=False):
+    return ColoredString('BLUE', string, always_color=always, bold=bold)
 
-def magenta(string, always=False):
-    return ColoredString('MAGENTA', string, always_color=always)
+def magenta(string, always=False, bold=False):
+    return ColoredString('MAGENTA', string, always_color=always, bold=bold)
 
-def cyan(string, always=False):
-    return ColoredString('CYAN', string, always_color=always)
+def cyan(string, always=False, bold=False):
+    return ColoredString('CYAN', string, always_color=always, bold=bold)
 
-def white(string, always=False):
-    return ColoredString('WHITE', string, always_color=always)
+def white(string, always=False, bold=False):
+    return ColoredString('WHITE', string, always_color=always, bold=bold)
 
 def disable():
     """Disables colors."""
